pub struct WatchDogChannels {
pub tx_watchdog_to_signal_handler: AquaSender<bool>,
pub rx_watchdog_from_signal_handler: AquaReceiver<InternalCommand>,
pub rx_watchdog_from_messaging_opt: Option<AquaReceiver<InternalCommand>>,
}Fields
tx_watchdog_to_signal_handler: AquaSender<bool>rx_watchdog_from_signal_handler: AquaReceiver<InternalCommand>rx_watchdog_from_messaging_opt: Option<AquaReceiver<InternalCommand>>Implementations
Sourceimpl WatchDogChannels
impl WatchDogChannels
Sourcepub fn send_to_signal_handler(
&mut self,
ack: bool,
) -> Result<(), AquaChannelError>
pub fn send_to_signal_handler( &mut self, ack: bool, ) -> Result<(), AquaChannelError>
Sends an acknowledgment to the signal handler.
This wrapper function sends a boolean acknowledgment and increments the
associated debug counter if the debug_channels feature is enabled and
the send operation is successful.
Sourcepub fn receive_from_signal_handler(
&mut self,
) -> Result<InternalCommand, AquaChannelError>
pub fn receive_from_signal_handler( &mut self, ) -> Result<InternalCommand, AquaChannelError>
Receives a command from the signal handler (non-blocking).
This wrapper function performs a non-blocking receive-operation for a command and increments
the associated debug counter if the debug_channels feature is enabled and a
message is successfully received.
Sourcepub fn receive_from_messaging(
&mut self,
) -> Option<Result<InternalCommand, AquaChannelError>>
pub fn receive_from_messaging( &mut self, ) -> Option<Result<InternalCommand, AquaChannelError>>
Receives a command from the messaging module, if the channel exists (non-blocking).
This wrapper function performs a non-blocking receive-operation and increments the
associated debug counter if the debug_channels feature is enabled and a
message is successfully received.